# -*- coding: utf-8 -*-
from setuphelpers import *
import os


r"""
https://www.adobe.com/devnet-docs/acrobatetk/tools/PrefRef/Windows/AVGeneral.html
https://www.adobe.com/devnet-docs/acrobatetk/tools/PrefRef/Windows/FeatureLockDown.html

"""
adobe_arm_registry_dict = {
    r"ARM\iCheck": 0,  # https://www.adobe.com/devnet-docs/acrobatetk/tools/PrefRef/Windows/Updater-Win.html#idkeyname_1_30198
    r"ARM\iCheckReader": 0,
    r"ARM\iDisablePromptForUpgrade": 1,
}
adobe_acrobat_registry_dict = {
    r"FeatureLockDown\bUpdateToSingleApp": 0,  # https://helpx.adobe.com/acrobat/kb/about-acrobat-reader-dc-migration-to-64-bit.html
    r"FeatureLockDown\bUpdater": 0,  # https://www.adobe.com/devnet-docs/acrobatetk/tools/PrefRef/Windows/FeatureLockDown.html#idkeyname_1_9111
    r"FeatureLockDown\bUsageMeasurement": 0,
    # r"FeatureLockDown\bSuppressSignOut": 1,
    r"FeatureLockDown\bToggleFTE": 1,
    r"FeatureLockDown\bAcroSuppressUpsell": 1,
    r"FeatureLockDown\cWelcomeScreen\bShowWelcomeScreen": 0,
    r"FeatureLockDown\cCloud\bEnableAcrobatHS": 0,
    r"FeatureLockDown\cServices\bUpdater": 0,
    r"FeatureLockDown\cServices\bToggleAdobeDocumentServices": 1,
    r"FeatureLockDown\cServices\bToggleWebConnectors": 1,  # https://www.adobe.com/devnet-docs/acrobatetk/tools/PrefRef/Windows/FeatureLockDown.html#idkeyname_1_9878
    r"FeatureLockDown\cServices\bToggleSendAndTrack": 1,
    # r"FeatureLockDown\cServices\bTogglePrefsSync": 1,
    # r"FeatureLockDown\cServices\bToggleFillSign": 1,
    r"FeatureLockDown\cServices\bToggleWebConnectors": 1,
}
adobe_acrobat_user_registry_dict = {
    r"Originals\iDefaultZoomScale": 10000,  # Zoom 100% by default (https://www.adobe.com/devnet-docs/acrobatetk/tools/PrefRef/Windows/Originals.html#idkeyname_1_17361)
    r"AVGeneral\cOnboardingContextual\bIsUsedShareReview": 1,  # https://www.adobe.com/devnet-docs/acrobatetk/tools/PrefRef/Windows/AVGeneral.html#idkeyname_1_5265
    r"AVTracker\bLoadOnStart": 1,  # https://www.adobe.com/devnet-docs/acrobatetk/tools/PrefRef/Macintosh/AVTracker.html?zoom_highlight=AdobeCollabSync.exe#TrackerConfiguration
    r"Access\bOverridePageLayout": 1,
    r"Access\bOverrideZoom": 1,
    r"Access\iZoomType": 0,
}


def install():
    # Checking if application is installed
    app_check = installed_softwares("Adobe Acrobat ")
    if not app_check:
        error('Adobe Acrobat is not installed. You may want to install "tis-adobereader" or "tis-adobe-acrobat-pro".')
    else:
        is_win64_app = app_check[0]["win64"]

    # Disabling automatic updates, telemetry and intrusive services
    if iswin64() and is_win64_app:
        # 64bit PC and app
        for reg_path, reg_value in adobe_arm_registry_dict.items():
            reg_short_path = reg_path.rsplit(os.sep, 1)[0]
            keyname = reg_path.rsplit(os.sep, 1)[-1]
            registry_set(HKEY_LOCAL_MACHINE, rf"SOFTWARE\Adobe\Adobe ARM\1.0\{reg_short_path}", keyname, reg_value)
        for reg_path, reg_value in adobe_acrobat_registry_dict.items():
            reg_short_path = reg_path.rsplit(os.sep, 1)[0]
            keyname = reg_path.rsplit(os.sep, 1)[-1]
            registry_set(HKEY_LOCAL_MACHINE, rf"SOFTWARE\Policies\Adobe\Adobe Acrobat\DC\{reg_short_path}", keyname, reg_value)
    elif iswin64() and not is_win64_app:
        # 64bit PC but 32bit app
        for reg_path, reg_value in adobe_arm_registry_dict.items():
            reg_short_path = reg_path.rsplit(os.sep, 1)[0]
            keyname = reg_path.rsplit(os.sep, 1)[-1]
            registry_set(HKEY_LOCAL_MACHINE, rf"SOFTWARE\Wow6432Node\Adobe\Adobe ARM\1.0\{reg_short_path}", keyname, reg_value)
        for reg_path, reg_value in adobe_acrobat_registry_dict.items():
            reg_short_path = reg_path.rsplit(os.sep, 1)[0]
            keyname = reg_path.rsplit(os.sep, 1)[-1]
            registry_set(HKEY_LOCAL_MACHINE, rf"SOFTWARE\Wow6432Node\Policies\Adobe\Acrobat Reader\DC\{reg_short_path}", keyname, reg_value)
    else:
        # 32bit PC
        for reg_path, reg_value in adobe_arm_registry_dict.items():
            reg_short_path = reg_path.rsplit(os.sep, 1)[0]
            keyname = reg_path.rsplit(os.sep, 1)[-1]
            registry_set(HKEY_LOCAL_MACHINE, rf"SOFTWARE\Adobe\Adobe ARM\1.0\{reg_short_path}", keyname, reg_value)
        for reg_path, reg_value in adobe_acrobat_registry_dict.items():
            reg_short_path = reg_path.rsplit(os.sep, 1)[0]
            keyname = reg_path.rsplit(os.sep, 1)[-1]
            registry_set(HKEY_LOCAL_MACHINE, rf"SOFTWARE\Policies\Adobe\Acrobat Reader\DC\{reg_short_path}", keyname, reg_value)


def session_setup():
    is_win64_app = installed_softwares("Adobe Acrobat ")[0]["win64"]
    if is_win64_app:
        # registry_deletekey(HKEY_CURRENT_USER, r"Software\Adobe", "Acrobat Reader")
        for reg_path, reg_value in adobe_acrobat_user_registry_dict.items():
            reg_short_path = reg_path.rsplit(os.sep, 1)[0]
            keyname = reg_path.rsplit(os.sep, 1)[-1]
            registry_set(HKEY_CURRENT_USER, rf"Software\Adobe\Adobe Acrobat\DC\{reg_short_path}", keyname, reg_value)
    else:
        # registry_deletekey(HKEY_CURRENT_USER, r"Software\Adobe", "Adobe Acrobat")
        for reg_path, reg_value in adobe_acrobat_user_registry_dict.items():
            reg_short_path = reg_path.rsplit(os.sep, 1)[0]
            keyname = reg_path.rsplit(os.sep, 1)[-1]
            registry_set(HKEY_CURRENT_USER, rf"Software\Adobe\Acrobat Reader\DC\{reg_short_path}", keyname, reg_value)


def uninstall():
    registry_deletekey(HKEY_LOCAL_MACHINE, r"SOFTWARE\Adobe\Adobe ARM\1.0", "ARM")
    registry_deletekey(HKEY_LOCAL_MACHINE, r"SOFTWARE\Wow6432Node\Adobe\Adobe ARM\1.0", "ARM")
    registry_deletekey(HKEY_LOCAL_MACHINE, r"SOFTWARE\Policies\Adobe\Adobe Acrobat\DC", "FeatureLockDown")
    registry_deletekey(HKEY_LOCAL_MACHINE, r"SOFTWARE\Policies\Adobe\Acrobat Reader\DC", "FeatureLockDown")
    registry_deletekey(HKEY_LOCAL_MACHINE, r"SOFTWARE\Wow6432Node\Policies\Adobe\Acrobat Reader\DC", "FeatureLockDown")
